# allinclusive_API

initial commit, working example for testing purposes

# Python Module for Roxibus communication

This is contains a python module for ROXi bus communication
libRoxi DLL Version = 15. 2. 2021

Install using:
`python setup.py install`

# Publishing Package

Python package is automatically published when using tag :vX.Y.Z; **(Prefixed by v)**
See automation flow in .github/workflows folder.
See https://pypi.org/project/RoxiLib/#history for published releases.
